@@ -148,7 +148,7 @@ cipher_hash_id (GMimeCipherContext *ctx, const char *hash)
  *
  * Gets the hash id based on the hash name @hash.
  *
- * Returns the equivalent hash id or #GMIME_CIPHER_HASH_DEFAULT on fail.
+ * Returns: the equivalent hash id or #GMIME_CIPHER_HASH_DEFAULT on fail.
  **/
 GMimeCipherHash
 g_mime_cipher_context_hash_id (GMimeCipherContext *ctx, const char *hash)
@@ -174,7 +174,7 @@ cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
  *
  * Gets the hash name based on the hash id @hash.
  *
- * Returns the equivalent hash name or %NULL on fail.
+ * Returns: the equivalent hash name or %NULL on fail.
  **/
 const char *
 g_mime_cipher_context_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
@@ -207,7 +207,7 @@ cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
  *
  * Signs the input stream and writes the resulting signature to the output stream.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
 g_mime_cipher_context_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
@@ -245,7 +245,7 @@ cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istre
  * @sigstream is assumed to be the signature stream and is used to
  * verify the integirity of the @istream.
  *
- * Returns a #GMimeSignatureValidity structure containing information
+ * Returns: a #GMimeSignatureValidity structure containing information
  * about the integrity of the input stream or %NULL on failure to
  * execute at all.
  **/
@@ -284,7 +284,7 @@ cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtr
  * Encrypts (and optionally signs) the cleartext input stream and
  * writes the resulting ciphertext to the output stream.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
 g_mime_cipher_context_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtrArray *recipients,
@@ -319,7 +319,7 @@ cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
  * Decrypts the ciphertext input stream and writes the resulting
  * cleartext to the output stream.
  *
- * Returns %0 on success or %-1 for fail.
+ * Returns: %0 on success or %-1 for fail.
  **/
 int
 g_mime_cipher_context_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
@@ -352,7 +352,7 @@ cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
  * Imports a stream of keys/certificates contained within @istream
  * into the key/certificate database controlled by @ctx.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
 g_mime_cipher_context_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
@@ -385,7 +385,7 @@ cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
  * Exports the keys/certificates in @keys to the stream @ostream from
  * the key/certificate database controlled by @ctx.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
 g_mime_cipher_context_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
@@ -404,7 +404,7 @@ g_mime_cipher_context_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
  *
  * Allocates an new GMimeSigner.
  *
- * Returns a new #GMimeSigner.
+ * Returns: a new #GMimeSigner.
  **/
 GMimeSigner *
 g_mime_signer_new (void)
@@ -415,8 +415,8 @@ g_mime_signer_new (void)
 	signer->status = GMIME_SIGNER_STATUS_NONE;
 	signer->errors = GMIME_SIGNER_ERROR_NONE;
 	signer->trust = GMIME_SIGNER_TRUST_NONE;
-	signer->sig_created = (time_t) 0;
-	signer->sig_expire = (time_t) 0;
+	signer->created = (time_t) 0;
+	signer->expires = (time_t) 0;
 	signer->fingerprint = NULL;
 	signer->keyid = NULL;
 	signer->name = NULL;
@@ -442,12 +442,296 @@ g_mime_signer_free (GMimeSigner *signer)
 }
 
 
+/**
+ * g_mime_signer_next:
+ * @signer: a #GMimeSigner
+ *
+ * Advance to the next signer.
+ *
+ * Returns: the next #GMimeSigner or %NULL when complete.
+ **/
+GMimeSigner *
+g_mime_signer_next (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->next;
+}
+
+
+/**
+ * g_mime_signer_set_status:
+ * @signer: a #GMimeSigner
+ * @status: a #GMimeSignerStatus
+ *
+ * Set the status on the signer.
+ **/
+void
+g_mime_signer_set_status (GMimeSigner *signer, GMimeSignerStatus status)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->status = status;
+}
+
+
+/**
+ * g_mime_signer_get_status:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer status.
+ *
+ * Returns: the signer status.
+ **/
+GMimeSignerStatus
+g_mime_signer_get_status (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_STATUS_NONE);
+	
+	return signer->status;
+}
+
+
+/**
+ * g_mime_signer_set_errors:
+ * @signer: a #GMimeSigner
+ * @error: a #GMimeSignerError
+ *
+ * Set the errors on the signer.
+ **/
+void
+g_mime_signer_set_errors (GMimeSigner *signer, GMimeSignerError errors)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->errors = errors;
+}
+
+
+/**
+ * g_mime_signer_get_errors:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer errors.
+ *
+ * Returns: the signer errors.
+ **/
+GMimeSignerError
+g_mime_signer_get_error (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_ERROR_NONE);
+	
+	return signer->errors;
+}
+
+
+/**
+ * g_mime_signer_set_trust:
+ * @signer: a #GMimeSigner
+ * @trust: a #GMimeSignerTrust
+ *
+ * Set the signer trust.
+ **/
+void
+g_mime_signer_set_trust (GMimeSigner *signer, GMimeSignerTrust trust)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->trust = trust;
+}
+
+
+/**
+ * g_mime_signer_get_trust:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer trust.
+ *
+ * Returns: the signer trust.
+ **/
+GMimeSignerTrust
+g_mime_signer_get_trust (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_TRUST_NONE);
+	
+	return signer->trust;
+}
+
+
+/**
+ * g_mime_signer_set_fingerprint:
+ * @signer: a #GMimeSigner
+ * @fingerprint: fingerprint string
+ *
+ * Set the signer's key fingerprint.
+ **/
+void
+g_mime_signer_set_fingerprint (GMimeSigner *signer, const char *fingerprint)
+{
+	g_return_if_fail (signer != NULL);
+	
+	g_free (signer->fingerprint);
+	signer->fingerprint = g_strdup (fingerprint);
+}
+
+
+/**
+ * g_mime_signer_get_fingerprint:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer's key fingerprint.
+ *
+ * Returns: the signer's key fingerprint.
+ **/
+const char *
+g_mime_signer_get_fingerprint (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->fingerprint;
+}
+
+
+/**
+ * g_mime_signer_set_key_id:
+ * @signer: a #GMimeSigner
+ * @key_id: key id
+ *
+ * Set the signer's key id.
+ **/
+void
+g_mime_signer_set_key_id (GMimeSigner *signer, const char *key_id)
+{
+	g_return_if_fail (signer != NULL);
+	
+	g_free (signer->keyid);
+	signer->keyid = g_strdup (key_id);
+}
+
+
+/**
+ * g_mime_signer_get_key_id:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer's key id.
+ *
+ * Returns: the signer's key id.
+ **/
+const char *
+g_mime_signer_get_key_id (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->keyid;
+}
+
+
+/**
+ * g_mime_signer_set_name:
+ * @signer: a #GMimeSigner
+ * @name: signer's name
+ *
+ * Set the signer's name.
+ **/
+void
+g_mime_signer_set_name (GMimeSigner *signer, const char *name)
+{
+	g_return_if_fail (signer != NULL);
+	
+	g_free (signer->name);
+	signer->name = g_strdup (name);
+}
+
+
+/**
+ * g_mime_signer_get_name:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer trust.
+ *
+ * Returns: the signer trust.
+ **/
+const char *
+g_mime_signer_get_name (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->name;
+}
+
+
+/**
+ * g_mime_signer_set_created:
+ * @signer: a #GMimeSigner
+ * @created: creation date
+ *
+ * Set the signer's key creation date.
+ **/
+void
+g_mime_signer_set_created (GMimeSigner *signer, time_t created)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->created = created;
+}
+
+
+/**
+ * g_mime_signer_get_created:
+ * @signer: a #GMimeSigner
+ *
+ * Get the creation date of the signer's key.
+ *
+ * Returns: the creation date of the signer's key.
+ **/
+time_t
+g_mime_signer_get_created (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, (time_t) -1);
+	
+	return signer->created;
+}
+
+
+/**
+ * g_mime_signer_set_expires:
+ * @signer: a #GMimeSigner
+ * @expires: expiration date
+ *
+ * Set the signer's key expiration date.
+ **/
+void
+g_mime_signer_set_expires (GMimeSigner *signer, time_t expires)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->expires = expires;
+}
+
+
+/**
+ * g_mime_signer_get_expires:
+ * @signer: a #GMimeSigner
+ *
+ * Get the expiration date of the signer's key.
+ *
+ * Returns: the expiration date of the signer's key.
+ **/
+time_t
+g_mime_signer_get_expires (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, (time_t) -1);
+	
+	return signer->expires;
+}
+
+
 /**
  * g_mime_signature_validity_new:
  *
  * Creates a new #GMimeSignatureValidity.
  *
- * Returns a new #GMimeSignatureValidity.
+ * Returns: a new #GMimeSignatureValidity.
  **/
 GMimeSignatureValidity *
 g_mime_signature_validity_new (void)
@@ -499,7 +783,7 @@ g_mime_signature_validity_free (GMimeSignatureValidity *validity)
  *
  * Gets the signature status (GOOD, BAD, UNKNOWN).
  *
- * Returns a #GMimeSignatureStatus value.
+ * Returns: a #GMimeSignatureStatus value.
  **/
 GMimeSignatureStatus
 g_mime_signature_validity_get_status (GMimeSignatureValidity *validity)
@@ -533,7 +817,7 @@ g_mime_signature_validity_set_status (GMimeSignatureValidity *validity, GMimeSig
  *
  * Gets any user-readable status details.
  *
- * Returns a user-readable string containing any status information.
+ * Returns: a user-readable string containing any status information.
  **/
 const char *
 g_mime_signature_validity_get_details (GMimeSignatureValidity *validity)
@@ -567,7 +851,7 @@ g_mime_signature_validity_set_details (GMimeSignatureValidity *validity, const c
  *
  * Gets the list of signers.
  *
- * Returns a #GMimeSigner list which contain further information such
+ * Returns: a #GMimeSigner list which contain further information such
  * as trust and cipher keys.
  **/
 const GMimeSigner *
