@@ -52,6 +52,10 @@ typedef struct _GMimeSignatureValidity GMimeSignatureValidity;
  * @GMIME_CIPHER_HASH_MD2: The MD2 hash algorithm.
  * @GMIME_CIPHER_HASH_MD5: The MD5 hash algorithm.
  * @GMIME_CIPHER_HASH_SHA1: The SHA-1 hash algorithm.
+ * @GMIME_CIPHER_HASH_SHA224: The SHA-224 hash algorithm.
+ * @GMIME_CIPHER_HASH_SHA256: The SHA-256 hash algorithm.
+ * @GMIME_CIPHER_HASH_SHA384: The SHA-384 hash algorithm.
+ * @GMIME_CIPHER_HASH_SHA512: The SHA-512 hash algorithm.
  * @GMIME_CIPHER_HASH_RIPEMD160: The RIPEMD-160 hash algorithm.
  * @GMIME_CIPHER_HASH_TIGER192: The TIGER-192 hash algorithm.
  * @GMIME_CIPHER_HASH_HAVAL5160: The HAVAL-5160 hash algorithm.
@@ -63,6 +67,10 @@ typedef enum {
 	GMIME_CIPHER_HASH_MD2,
 	GMIME_CIPHER_HASH_MD5,
 	GMIME_CIPHER_HASH_SHA1,
+	GMIME_CIPHER_HASH_SHA224,
+	GMIME_CIPHER_HASH_SHA256,
+	GMIME_CIPHER_HASH_SHA384,
+	GMIME_CIPHER_HASH_SHA512,
 	GMIME_CIPHER_HASH_RIPEMD160,
 	GMIME_CIPHER_HASH_TIGER192,
 	GMIME_CIPHER_HASH_HAVAL5160
@@ -112,36 +120,34 @@ struct _GMimeCipherContextClass {
 
 GType g_mime_cipher_context_get_type (void);
 
-
 /* hash routines */
-GMimeCipherHash      g_mime_cipher_hash_id (GMimeCipherContext *ctx, const char *hash);
+GMimeCipherHash      g_mime_cipher_context_hash_id (GMimeCipherContext *ctx, const char *hash);
 
-const char *         g_mime_cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash);
+const char *         g_mime_cipher_context_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash);
 
 /* cipher routines */
-int                  g_mime_cipher_sign (GMimeCipherContext *ctx, const char *userid,
-					 GMimeCipherHash hash, GMimeStream *istream,
-					 GMimeStream *ostream, GError **err);
+int                  g_mime_cipher_context_sign (GMimeCipherContext *ctx, const char *userid,
+						 GMimeCipherHash hash, GMimeStream *istream,
+						 GMimeStream *ostream, GError **err);
 
-GMimeSignatureValidity *g_mime_cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash,
-					      GMimeStream *istream, GMimeStream *sigstream,
-					      GError **err);
+GMimeSignatureValidity *g_mime_cipher_context_verify (GMimeCipherContext *ctx, GMimeCipherHash hash,
+						      GMimeStream *istream, GMimeStream *sigstream,
+						      GError **err);
 
-int                  g_mime_cipher_encrypt (GMimeCipherContext *ctx, gboolean sign,
-					    const char *userid, GPtrArray *recipients,
-					    GMimeStream *istream, GMimeStream *ostream,
-					    GError **err);
+int                  g_mime_cipher_context_encrypt (GMimeCipherContext *ctx, gboolean sign,
+						    const char *userid, GPtrArray *recipients,
+						    GMimeStream *istream, GMimeStream *ostream,
+						    GError **err);
 
-int                  g_mime_cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
-					    GMimeStream *ostream, GError **err);
+int                  g_mime_cipher_context_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
+						    GMimeStream *ostream, GError **err);
 
 /* key/certificate routines */
-int                  g_mime_cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream,
-						GError **err);
-
-int                  g_mime_cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
-						GMimeStream *ostream, GError **err);
+int                  g_mime_cipher_context_import_keys (GMimeCipherContext *ctx, GMimeStream *istream,
+							GError **err);
 
+int                  g_mime_cipher_context_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
+							GMimeStream *ostream, GError **err);
 
 
 /* signature status structures and functions */
@@ -211,8 +217,8 @@ typedef enum {
  * @errors: A bitfield of #GMimeSignerError values.
  * @trust: A #GMimeSignerTrust.
  * @unused: Unused expansion bits for future use; ignore this.
- * @sig_created: The creation date of the signature.
- * @sig_expire: The expiration date of the signature.
+ * @created: The creation date of the signature.
+ * @expires: The expiration date of the signature.
  * @fingerprint: A hex string representing the signer's fingerprint.
  * @keyid: The signer's key id.
  * @name: The name of the person or entity.
@@ -225,9 +231,9 @@ struct _GMimeSigner {
 	unsigned int errors:4;    /* bitfield of GMimeSignerError's */
 	unsigned int trust:3;     /* GMimeSignerTrust */
 	unsigned int unused:23;   /* unused expansion bits */
-	time_t sig_created;
-	time_t sig_expire;
 	char *fingerprint;
+	time_t created;
+	time_t expires;
 	char *keyid;
 	char *name;
 };
@@ -236,6 +242,33 @@ struct _GMimeSigner {
 GMimeSigner *g_mime_signer_new (void);
 void         g_mime_signer_free (GMimeSigner *signer);
 
+GMimeSigner *g_mime_signer_next (GMimeSigner *signer);
+
+void g_mime_signer_set_status (GMimeSigner *signer, GMimeSignerStatus status);
+GMimeSignerStatus g_mime_signer_get_status (GMimeSigner *signer);
+
+void g_mime_signer_set_errors (GMimeSigner *signer, GMimeSignerError error);
+GMimeSignerError g_mime_signer_get_errors (GMimeSigner *signer);
+
+void g_mime_signer_set_trust (GMimeSigner *signer, GMimeSignerTrust trust);
+GMimeSignerTrust g_mime_signer_get_trust (GMimeSigner *signer);
+
+void g_mime_signer_set_fingerprint (GMimeSigner *signer, const char *fingerprint);
+const char *g_mime_signer_get_fingerprint (GMimeSigner *signer);
+
+void g_mime_signer_set_key_id (GMimeSigner *signer, const char *key_id);
+const char *g_mime_signer_get_key_id (GMimeSigner *signer);
+
+void g_mime_signer_set_name (GMimeSigner *signer, const char *name);
+const char *g_mime_signer_get_name (GMimeSigner *signer);
+
+void g_mime_signer_set_created (GMimeSigner *signer, time_t created);
+time_t g_mime_signer_get_created (GMimeSigner *signer);
+
+void g_mime_signer_set_expires (GMimeSigner *signer, time_t expires);
+time_t g_mime_signer_get_expires (GMimeSigner *signer);
+
+
 
 /**
  * GMimeSignatureStatus:
@@ -282,31 +315,6 @@ void                    g_mime_signature_validity_set_details (GMimeSignatureVal
 const GMimeSigner      *g_mime_signature_validity_get_signers (GMimeSignatureValidity *validity);
 void                    g_mime_signature_validity_add_signer  (GMimeSignatureValidity *validity, GMimeSigner *signer);
 
-
-#ifndef GMIME_DISABLE_DEPRECATED
-
-/* for backward compatability */
-typedef struct _GMimeSignatureValidity GMimeCipherValidity;
-
-GMimeCipherValidity *g_mime_cipher_validity_new (void);
-
-void                 g_mime_cipher_validity_init (GMimeCipherValidity *validity);
-
-gboolean             g_mime_cipher_validity_get_valid (GMimeCipherValidity *validity);
-
-void                 g_mime_cipher_validity_set_valid (GMimeCipherValidity *validity, gboolean valid);
-
-const char          *g_mime_cipher_validity_get_description (GMimeCipherValidity *validity);
-
-void                 g_mime_cipher_validity_set_description (GMimeCipherValidity *validity,
-							     const char *description);
-
-void                 g_mime_cipher_validity_clear (GMimeCipherValidity *validity);
-
-void                 g_mime_cipher_validity_free (GMimeCipherValidity *validity);
-
-#endif /* GMIME_DISABLE_DEPRECATED */
-
 G_END_DECLS
 
 #endif /* __GMIME_CIPHER_CONTEXT_H__ */
