@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -184,6 +184,14 @@ gpg_hash_id (GMimeCipherContext *ctx, const char *hash)
 		return GMIME_CIPHER_HASH_MD5;
 	else if (!g_ascii_strcasecmp (hash, "sha1"))
 		return GMIME_CIPHER_HASH_SHA1;
+	else if (!g_ascii_strcasecmp (hash, "sha224"))
+		return GMIME_CIPHER_HASH_SHA224;
+	else if (!g_ascii_strcasecmp (hash, "sha256"))
+		return GMIME_CIPHER_HASH_SHA256;
+	else if (!g_ascii_strcasecmp (hash, "sha384"))
+		return GMIME_CIPHER_HASH_SHA384;
+	else if (!g_ascii_strcasecmp (hash, "sha512"))
+		return GMIME_CIPHER_HASH_SHA512;
 	else if (!g_ascii_strcasecmp (hash, "ripemd160"))
 		return GMIME_CIPHER_HASH_RIPEMD160;
 	else if (!g_ascii_strcasecmp (hash, "tiger192"))
@@ -204,6 +212,14 @@ gpg_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
 		return "pgp-md5";
 	case GMIME_CIPHER_HASH_SHA1:
 		return "pgp-sha1";
+	case GMIME_CIPHER_HASH_SHA224:
+		return "pgp-sha224";
+	case GMIME_CIPHER_HASH_SHA256:
+		return "pgp-sha256";
+	case GMIME_CIPHER_HASH_SHA384:
+		return "pgp-sha384";
+	case GMIME_CIPHER_HASH_SHA512:
+		return "pgp-sha512";
 	case GMIME_CIPHER_HASH_RIPEMD160:
 		return "pgp-ripemd160";
 	case GMIME_CIPHER_HASH_TIGER192:
@@ -768,34 +784,6 @@ next_token (char *in, char **token)
 	return inptr;
 }
 
-/**
- * gpg_ctx_add_signer:
- * @gpg: GnuPG context
- * @info: a string with the signer's info
- *
- * Parses GOODSIG, BADSIG, EXPSIG, EXPKEYSIG, and REVKEYSIG status messages
- * into a newly allocated #GMimeSigner, adding it to @gpg's signer list.
- *
- * Returns: the newly added signer for the caller to add more info to.
- **/
-static GMimeSigner *
-gpg_ctx_add_signer (struct _GpgCtx *gpg, char *info)
-{
-	GMimeSigner *signer;
-	
-	signer = g_mime_signer_new ();
-	gpg->signer->next = signer;
-	gpg->signer = signer;
-	
-	/* get the key id of the signer */
-	info = next_token (info, &signer->keyid);
-	
-	/* the rest of the string is the signer's name */
-	signer->name = g_strdup (info);
-	
-	return signer;
-}
-
 static int
 gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 {
@@ -997,20 +985,33 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 			if (!strncmp (status, "SIG_ID ", 7)) {
 				/* not sure if this contains anything we care about... */
 			} else if (!strncmp (status, "GOODSIG ", 8)) {
-				signer = gpg_ctx_add_signer (gpg, status + 8);
 				gpg->goodsig = TRUE;
+				status += 8;
+				
+				signer = g_mime_signer_new ();
+				signer->status = GMIME_SIGNER_STATUS_GOOD;
+				gpg->signer->next = signer;
+				gpg->signer = signer;
+				
+				/* get the key id of the signer */
+				status = next_token (status, &signer->keyid);
+				
+				/* the rest of the string is the signer's name */
+				signer->name = g_strdup (status);
 			} else if (!strncmp (status, "BADSIG ", 7)) {
-				signer = gpg_ctx_add_signer (gpg, status + 7);
 				gpg->badsig = TRUE;
-			} else if (!strncmp (status, "EXPSIG ", 7)) {
-				signer = gpg_ctx_add_signer (gpg, status + 7);
-				signer->errors |= GMIME_SIGNER_ERROR_EXPSIG;
-			} else if (!strncmp (status, "EXPKEYSIG ", 10)) {
-				signer = gpg_ctx_add_signer (gpg, status + 10);
-				signer->errors |= GMIME_SIGNER_ERROR_EXPKEYSIG;
-			} else if (!strncmp (status, "REVKEYSIG ", 10)) {
-				signer = gpg_ctx_add_signer (gpg, status + 10);
-				signer->errors |= GMIME_SIGNER_ERROR_REVKEYSIG;
+				status += 7;
+				
+				signer = g_mime_signer_new ();
+				signer->status = GMIME_SIGNER_STATUS_BAD;
+				gpg->signer->next = signer;
+				gpg->signer = signer;
+				
+				/* get the key id of the signer */
+				status = next_token (status, &signer->keyid);
+				
+				/* the rest of the string is the signer's name */
+				signer->name = g_strdup (status);
 			} else if (!strncmp (status, "ERRSIG ", 7)) {
 				/* Note: NO_PUBKEY often comes after an ERRSIG */
 				gpg->errsig = TRUE;
@@ -1034,7 +1035,7 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 				status = next_token (status, NULL);
 				
 				/* get the signature expiration date (or 0 for never) */
-				signer->sig_expire = strtoul (status, NULL, 10);
+				signer->expires = strtoul (status, NULL, 10);
 				status = next_token (status, NULL);
 				
 				/* the last token is the 'rc' which we don't care about */
@@ -1042,6 +1043,13 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 				/* the only token is the keyid, but we've already got it */
 				gpg->signer->errors |= GMIME_SIGNER_ERROR_NO_PUBKEY;
 				gpg->nopubkey = TRUE;
+			} else if (!strncmp (status, "EXPSIG", 6)) {
+				/* FIXME: see what else we can glean from this... */
+				gpg->signer->errors |= GMIME_SIGNER_ERROR_EXPSIG;
+			} else if (!strncmp (status, "EXPKEYSIG", 9)) {
+				gpg->signer->errors |= GMIME_SIGNER_ERROR_EXPKEYSIG;
+			} else if (!strncmp (status, "REVKEYSIG", 9)) {
+				gpg->signer->errors |= GMIME_SIGNER_ERROR_REVKEYSIG;
 			} else if (!strncmp (status, "VALIDSIG ", 9)) {
 				char *inend;
 				
@@ -1057,14 +1065,14 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, GError **err)
 				status = next_token (status, NULL);
 				
 				/* the third token is the signature creation date (or 0 for unknown?) */
-				signer->sig_created = strtoul (status, &inend, 10);
+				signer->created = strtoul (status, &inend, 10);
 				if (inend == status || *inend != ' ')
 					break;
 				
 				status = inend + 1;
 				
 				/* the fourth token is the signature expiration date (or 0 for never) */
-				signer->sig_expire = strtoul (status, NULL, 10);
+				signer->expires = strtoul (status, NULL, 10);
 				
 				/* ignore the rest... */
 			} else if (!strncmp (status, "TRUST_", 6)) {
@@ -1847,7 +1855,7 @@ gpg_export_keys (GMimeCipherContext *context, GPtrArray *keys, GMimeStream *ostr
  *
  * Creates a new gpg cipher context object.
  *
- * Returns a new gpg cipher context object.
+ * Returns: a new gpg cipher context object.
  **/
 GMimeCipherContext *
 g_mime_gpg_context_new (GMimeSession *session, const char *path)
@@ -1875,7 +1883,7 @@ g_mime_gpg_context_new (GMimeSession *session, const char *path)
  *
  * Gets the @always_trust flag on the gpg context.
  *
- * Returns the @always_trust flag on the gpg context.
+ * Returns: the @always_trust flag on the gpg context.
  **/
 gboolean
 g_mime_gpg_context_get_always_trust (GMimeGpgContext *ctx)
