@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -27,7 +27,7 @@
 
 #include "gmime-message-part.h"
 
-#define d(x)
+#define d(x) x
 
 
 /**
@@ -48,10 +48,11 @@ static void g_mime_message_part_finalize (GObject *object);
 
 /* GMimeObject class methods */
 static void message_part_init (GMimeObject *object);
-static void message_part_add_header (GMimeObject *object, const char *header, const char *value);
+static void message_part_prepend_header (GMimeObject *object, const char *header, const char *value);
+static void message_part_append_header (GMimeObject *object, const char *header, const char *value);
 static void message_part_set_header (GMimeObject *object, const char *header, const char *value);
 static const char *message_part_get_header (GMimeObject *object, const char *header);
-static void message_part_remove_header (GMimeObject *object, const char *header);
+static gboolean message_part_remove_header (GMimeObject *object, const char *header);
 static void message_part_set_content_type (GMimeObject *object, GMimeContentType *content_type);
 static char *message_part_get_headers (GMimeObject *object);
 static ssize_t message_part_write_to_stream (GMimeObject *object, GMimeStream *stream);
@@ -96,10 +97,11 @@ g_mime_message_part_class_init (GMimeMessagePartClass *klass)
 	gobject_class->finalize = g_mime_message_part_finalize;
 	
 	object_class->init = message_part_init;
-	object_class->add_header = message_part_add_header;
+	object_class->prepend_header = message_part_prepend_header;
+	object_class->append_header = message_part_append_header;
+	object_class->remove_header = message_part_remove_header;
 	object_class->set_header = message_part_set_header;
 	object_class->get_header = message_part_get_header;
-	object_class->remove_header = message_part_remove_header;
 	object_class->set_content_type = message_part_set_content_type;
 	object_class->get_headers = message_part_get_headers;
 	object_class->write_to_stream = message_part_write_to_stream;
@@ -131,13 +133,21 @@ message_part_init (GMimeObject *object)
 }
 
 static void
-message_part_add_header (GMimeObject *object, const char *header, const char *value)
+message_part_prepend_header (GMimeObject *object, const char *header, const char *value)
 {
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a message part */
-	
 	if (!g_ascii_strncasecmp ("Content-", header, 8))
-		GMIME_OBJECT_CLASS (parent_class)->add_header (object, header, value);
+		GMIME_OBJECT_CLASS (parent_class)->prepend_header (object, header, value);
+}
+
+static void
+message_part_append_header (GMimeObject *object, const char *header, const char *value)
+{
+	/* Make sure that the header is a Content-* header, else it
+           doesn't belong on a message part */
+	if (!g_ascii_strncasecmp ("Content-", header, 8))
+		GMIME_OBJECT_CLASS (parent_class)->append_header (object, header, value);
 }
 
 static void
@@ -149,7 +159,6 @@ message_part_set_header (GMimeObject *object, const char *header, const char *va
 	
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a message part */
-	
 	if (!g_ascii_strncasecmp ("Content-", header, 8))
 		GMIME_OBJECT_CLASS (parent_class)->set_header (object, header, value);
 }
@@ -159,21 +168,21 @@ message_part_get_header (GMimeObject *object, const char *header)
 {
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a message part */
-	
 	if (!g_ascii_strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 	else
 		return NULL;
 }
 
-static void
+static gboolean
 message_part_remove_header (GMimeObject *object, const char *header)
 {
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a message part */
+	if (g_ascii_strncasecmp ("Content-", header, 8) != 0)
+		return FALSE;
 	
-	if (!g_ascii_strncasecmp ("Content-", header, 8))
-		GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
+	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
 static void
@@ -196,7 +205,7 @@ message_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	ssize_t nwritten, total = 0;
 	
 	/* write the content headers */
-	if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
+	if ((nwritten = g_mime_header_list_write_to_stream (object->headers, stream)) == -1)
 		return -1;
 	
 	total += nwritten;
@@ -226,7 +235,7 @@ message_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * Creates a new MIME message part object with a default content-type
  * of message/@subtype.
  *
- * Returns an empty MIME message part object with a default
+ * Returns: an empty MIME message part object with a default
  * content-type of message/@subtype.
  **/
 GMimeMessagePart *
@@ -252,7 +261,7 @@ g_mime_message_part_new (const char *subtype)
  * Creates a new MIME message part object with a default content-type
  * of message/@subtype containing @message.
  *
- * Returns a MIME message part object with a default content-type of
+ * Returns: a MIME message part object with a default content-type of
  * message/@subtype containing @message.
  **/
 GMimeMessagePart *
@@ -296,15 +305,14 @@ g_mime_message_part_set_message (GMimeMessagePart *part, GMimeMessage *message)
  *
  * Gets the message object on the message part object @part.
  *
- * Returns the message part contained within @part.
+ * Returns: the message part contained within @part.
  **/
 GMimeMessage *
 g_mime_message_part_get_message (GMimeMessagePart *part)
 {
 	g_return_val_if_fail (GMIME_IS_MESSAGE_PART (part), NULL);
 	
-	if (part->message)
-		g_object_ref (part->message);
+	g_object_ref (part->message);
 	
 	return part->message;
 }
