@@ -49,8 +49,11 @@ static void g_mime_message_partial_finalize (GObject *object);
 
 /* GMimeObject class methods */
 static void message_partial_init (GMimeObject *object);
-static void message_partial_add_header (GMimeObject *object, const char *header, const char *value);
+static void message_partial_prepend_header (GMimeObject *object, const char *header, const char *value);
+static void message_partial_append_header (GMimeObject *object, const char *header, const char *value);
 static void message_partial_set_header (GMimeObject *object, const char *header, const char *value);
+static const char *message_partial_get_header (GMimeObject *object, const char *header);
+static gboolean message_partial_remove_header (GMimeObject *object, const char *header);
 static void message_partial_set_content_type (GMimeObject *object, GMimeContentType *content_type);
 
 
@@ -93,8 +96,11 @@ g_mime_message_partial_class_init (GMimeMessagePartialClass *klass)
 	gobject_class->finalize = g_mime_message_partial_finalize;
 	
 	object_class->init = message_partial_init;
-	object_class->add_header = message_partial_add_header;
+	object_class->prepend_header = message_partial_prepend_header;
+	object_class->append_header = message_partial_append_header;
+	object_class->remove_header = message_partial_remove_header;
 	object_class->set_header = message_partial_set_header;
+	object_class->get_header = message_partial_get_header;
 	object_class->set_content_type = message_partial_set_content_type;
 }
 
@@ -124,17 +130,23 @@ message_partial_init (GMimeObject *object)
 }
 
 static void
-message_partial_add_header (GMimeObject *object, const char *header, const char *value)
+message_partial_prepend_header (GMimeObject *object, const char *header, const char *value)
 {
 	/* RFC 1864 states that you cannot set a Content-MD5 on a message part */
 	if (!g_ascii_strcasecmp ("Content-MD5", header))
 		return;
 	
-	/* Make sure that the header is a Content-* header, else it
-           doesn't belong on a mime part */
+	GMIME_OBJECT_CLASS (parent_class)->prepend_header (object, header, value);
+}
+
+static void
+message_partial_append_header (GMimeObject *object, const char *header, const char *value)
+{
+	/* RFC 1864 states that you cannot set a Content-MD5 on a message part */
+	if (!g_ascii_strcasecmp ("Content-MD5", header))
+		return;
 	
-	if (!g_ascii_strncasecmp ("Content-", header, 8))
-		GMIME_OBJECT_CLASS (parent_class)->add_header (object, header, value);
+	GMIME_OBJECT_CLASS (parent_class)->append_header (object, header, value);
 }
 
 static void
@@ -144,11 +156,27 @@ message_partial_set_header (GMimeObject *object, const char *header, const char
 	if (!g_ascii_strcasecmp ("Content-MD5", header))
 		return;
 	
-	/* Make sure that the header is a Content-* header, else it
-           doesn't belong on a mime part */
+	GMIME_OBJECT_CLASS (parent_class)->set_header (object, header, value);
+}
+
+static const char *
+message_partial_get_header (GMimeObject *object, const char *header)
+{
+	/* RFC 1864 states that you cannot set a Content-MD5 on a message part */
+	if (!g_ascii_strcasecmp ("Content-MD5", header))
+		return NULL;
 	
-	if (!g_ascii_strncasecmp ("Content-", header, 8))
-		GMIME_OBJECT_CLASS (parent_class)->set_header (object, header, value);
+	return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
+}
+
+static gboolean
+message_partial_remove_header (GMimeObject *object, const char *header)
+{
+	/* RFC 1864 states that you cannot set a Content-MD5 on a message part */
+	if (!g_ascii_strcasecmp ("Content-MD5", header))
+		return FALSE;
+	
+	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
 static void
@@ -179,7 +207,7 @@ message_partial_set_content_type (GMimeObject *object, GMimeContentType *content
  *
  * Creates a new MIME message/partial object.
  *
- * Returns an empty MIME message/partial object.
+ * Returns: an empty MIME message/partial object.
  **/
 GMimeMessagePartial *
 g_mime_message_partial_new (const char *id, int number, int total)
@@ -217,7 +245,7 @@ g_mime_message_partial_new (const char *id, int number, int total)
  *
  * Gets the message/partial id parameter value.
  *
- * Returns the message/partial id or %NULL on fail.
+ * Returns: the message/partial id or %NULL on fail.
  **/
 const char *
 g_mime_message_partial_get_id (GMimeMessagePartial *partial)
@@ -234,7 +262,7 @@ g_mime_message_partial_get_id (GMimeMessagePartial *partial)
  *
  * Gets the message/partial part number.
  *
- * Returns the message/partial part number or %-1 on fail.
+ * Returns: the message/partial part number or %-1 on fail.
  **/
 int
 g_mime_message_partial_get_number (GMimeMessagePartial *partial)
@@ -252,7 +280,7 @@ g_mime_message_partial_get_number (GMimeMessagePartial *partial)
  * Gets the total number of message/partial parts needed to
  * reconstruct the original message.
  *
- * Returns the total number of message/partial parts needed to
+ * Returns: the total number of message/partial parts needed to
  * reconstruct the original message or -1 on fail.
  **/
 int
@@ -286,7 +314,7 @@ partial_compare (const void *v1, const void *v2)
  * Reconstructs the GMimeMessage from the given message/partial parts
  * in @partials.
  *
- * Returns a GMimeMessage object on success or %NULL on fail.
+ * Returns: a GMimeMessage object on success or %NULL on fail.
  **/
 GMimeMessage *
 g_mime_message_partial_reconstruct_message (GMimeMessagePartial **partials, size_t num)
@@ -356,22 +384,27 @@ g_mime_message_partial_reconstruct_message (GMimeMessagePartial **partials, size
 }
 
 
-static void
-header_copy (const char *name, const char *value, gpointer user_data)
-{
-	GMimeMessage *message = (GMimeMessage *) user_data;
-	
-	if (value)
-		g_mime_object_add_header (GMIME_OBJECT (message), name, value);
-}
-
 static GMimeMessage *
 message_partial_message_new (GMimeMessage *base)
 {
+	const char *name, *value;
 	GMimeMessage *message;
+	GMimeHeaderList *list;
+	GMimeHeaderIter *iter;
 	
 	message = g_mime_message_new (FALSE);
-	g_mime_header_foreach (GMIME_OBJECT (base)->headers, header_copy, message);
+	
+	list = ((GMimeObject *) base)->headers;
+	iter = g_mime_header_list_get_iter (list);
+	if (g_mime_header_iter_is_valid (iter)) {
+		do {
+			name = g_mime_header_iter_get_name (iter);
+			value = g_mime_header_iter_get_value (iter);
+			g_mime_object_append_header ((GMimeObject *) message, name, value);
+		} while (g_mime_header_iter_next (iter));
+	}
+	
+	g_mime_header_iter_free (iter);
 	
 	return message;
 }
@@ -388,7 +421,7 @@ message_partial_message_new (GMimeMessage *base)
  * @max_size bytes or fewer. @nparts is set to the number of
  * #GMimeMessagePartial objects created.
  *
- * Returns an array of #GMimeMessage objects and sets @nparts to th
+ * Returns: an array of #GMimeMessage objects and sets @nparts to th
  * number of messages returned or %NULL on fail.
  **/
 GMimeMessage **
@@ -402,7 +435,7 @@ g_mime_message_partial_split_message (GMimeMessage *message, size_t max_size, si
 	GPtrArray *parts;
 	size_t len, end;
 	const char *id;
-	off_t start;
+	gint64 start;
 	int i;
 	
 	*nparts = 0;
@@ -459,7 +492,7 @@ g_mime_message_partial_split_message (GMimeMessage *message, size_t max_size, si
 	for (i = 0; i < parts->len; i++) {
 		partial = g_mime_message_partial_new (id, i + 1, parts->len);
 		wrapper = g_mime_data_wrapper_new_with_stream (GMIME_STREAM (parts->pdata[i]),
-							       GMIME_PART_ENCODING_DEFAULT);
+							       GMIME_CONTENT_ENCODING_DEFAULT);
 		g_object_unref (parts->pdata[i]);
 		g_mime_part_set_content_object (GMIME_PART (partial), wrapper);
 		g_object_unref (wrapper);
