@@ -58,10 +58,11 @@ static void g_mime_multipart_encrypted_finalize (GObject *object);
 
 /* GMimeObject class methods */
 static void multipart_encrypted_init (GMimeObject *object);
-static void multipart_encrypted_add_header (GMimeObject *object, const char *header, const char *value);
+static void multipart_encrypted_prepend_header (GMimeObject *object, const char *header, const char *value);
+static void multipart_encrypted_append_header (GMimeObject *object, const char *header, const char *value);
 static void multipart_encrypted_set_header (GMimeObject *object, const char *header, const char *value);
 static const char *multipart_encrypted_get_header (GMimeObject *object, const char *header);
-static void multipart_encrypted_remove_header (GMimeObject *object, const char *header);
+static gboolean multipart_encrypted_remove_header (GMimeObject *object, const char *header);
 static void multipart_encrypted_set_content_type (GMimeObject *object, GMimeContentType *content_type);
 static char *multipart_encrypted_get_headers (GMimeObject *object);
 static ssize_t multipart_encrypted_write_to_stream (GMimeObject *object, GMimeStream *stream);
@@ -106,10 +107,11 @@ g_mime_multipart_encrypted_class_init (GMimeMultipartEncryptedClass *klass)
 	gobject_class->finalize = g_mime_multipart_encrypted_finalize;
 	
 	object_class->init = multipart_encrypted_init;
-	object_class->add_header = multipart_encrypted_add_header;
+	object_class->prepend_header = multipart_encrypted_prepend_header;
+	object_class->append_header = multipart_encrypted_append_header;
+	object_class->remove_header = multipart_encrypted_remove_header;
 	object_class->set_header = multipart_encrypted_set_header;
 	object_class->get_header = multipart_encrypted_get_header;
-	object_class->remove_header = multipart_encrypted_remove_header;
 	object_class->set_content_type = multipart_encrypted_set_content_type;
 	object_class->get_headers = multipart_encrypted_get_headers;
 	object_class->write_to_stream = multipart_encrypted_write_to_stream;
@@ -144,9 +146,15 @@ multipart_encrypted_init (GMimeObject *object)
 }
 
 static void
-multipart_encrypted_add_header (GMimeObject *object, const char *header, const char *value)
+multipart_encrypted_prepend_header (GMimeObject *object, const char *header, const char *value)
 {
-	GMIME_OBJECT_CLASS (parent_class)->add_header (object, header, value);
+	GMIME_OBJECT_CLASS (parent_class)->prepend_header (object, header, value);
+}
+
+static void
+multipart_encrypted_append_header (GMimeObject *object, const char *header, const char *value)
+{
+	GMIME_OBJECT_CLASS (parent_class)->append_header (object, header, value);
 }
 
 static void
@@ -161,10 +169,10 @@ multipart_encrypted_get_header (GMimeObject *object, const char *header)
 	return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 }
 
-static void
+static gboolean
 multipart_encrypted_remove_header (GMimeObject *object, const char *header)
 {
-	GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
+	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
 static void
@@ -198,7 +206,7 @@ multipart_encrypted_write_to_stream (GMimeObject *object, GMimeStream *stream)
  *
  * Creates a new MIME multipart/encrypted object.
  *
- * Returns an empty MIME multipart/encrypted object.
+ * Returns: an empty MIME multipart/encrypted object.
  **/
 GMimeMultipartEncrypted *
 g_mime_multipart_encrypted_new (void)
@@ -228,7 +236,7 @@ g_mime_multipart_encrypted_new (void)
  * encrypted #GMimeObject is set as the encrypted part of the
  * multipart/encrypted object @mpe.
  *
- * Returns %0 on success or %-1 on fail. If the encryption fails, an
+ * Returns: %0 on success or %-1 on fail. If the encryption fails, an
  * exception will be set on @err to provide information as to why the
  * failure occured.
  **/
@@ -322,7 +330,7 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
  * Attempts to decrypt the encrypted MIME part contained within the
  * multipart/encrypted object @mpe using the @ctx decryption context.
  *
- * Returns the decrypted MIME part on success or %NULL on fail. If the
+ * Returns: the decrypted MIME part on success or %NULL on fail. If the
  * decryption fails, an exception will be set on @err to provide
  * information as to why the failure occured.
  **/
