@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -34,6 +34,7 @@
 #include "gmime-filter-crlf.h"
 #include "gmime-stream-mem.h"
 #include "gmime-parser.h"
+#include "gmime-error.h"
 #include "gmime-part.h"
 
 #define d(x)
@@ -58,10 +59,11 @@ static void g_mime_multipart_signed_finalize (GObject *object);
 
 /* GMimeObject class methods */
 static void multipart_signed_init (GMimeObject *object);
-static void multipart_signed_add_header (GMimeObject *object, const char *header, const char *value);
+static void multipart_signed_prepend_header (GMimeObject *object, const char *header, const char *value);
+static void multipart_signed_append_header (GMimeObject *object, const char *header, const char *value);
 static void multipart_signed_set_header (GMimeObject *object, const char *header, const char *value);
 static const char *multipart_signed_get_header (GMimeObject *object, const char *header);
-static void multipart_signed_remove_header (GMimeObject *object, const char *header);
+static gboolean multipart_signed_remove_header (GMimeObject *object, const char *header);
 static void multipart_signed_set_content_type (GMimeObject *object, GMimeContentType *content_type);
 static char *multipart_signed_get_headers (GMimeObject *object);
 static ssize_t multipart_signed_write_to_stream (GMimeObject *object, GMimeStream *stream);
@@ -106,10 +108,11 @@ g_mime_multipart_signed_class_init (GMimeMultipartSignedClass *klass)
 	gobject_class->finalize = g_mime_multipart_signed_finalize;
 	
 	object_class->init = multipart_signed_init;
-	object_class->add_header = multipart_signed_add_header;
+	object_class->prepend_header = multipart_signed_prepend_header;
+	object_class->append_header = multipart_signed_append_header;
+	object_class->remove_header = multipart_signed_remove_header;
 	object_class->set_header = multipart_signed_set_header;
 	object_class->get_header = multipart_signed_get_header;
-	object_class->remove_header = multipart_signed_remove_header;
 	object_class->set_content_type = multipart_signed_set_content_type;
 	object_class->get_headers = multipart_signed_get_headers;
 	object_class->write_to_stream = multipart_signed_write_to_stream;
@@ -142,9 +145,15 @@ multipart_signed_init (GMimeObject *object)
 }
 
 static void
-multipart_signed_add_header (GMimeObject *object, const char *header, const char *value)
+multipart_signed_prepend_header (GMimeObject *object, const char *header, const char *value)
 {
-	GMIME_OBJECT_CLASS (parent_class)->add_header (object, header, value);
+	GMIME_OBJECT_CLASS (parent_class)->prepend_header (object, header, value);
+}
+
+static void
+multipart_signed_append_header (GMimeObject *object, const char *header, const char *value)
+{
+	GMIME_OBJECT_CLASS (parent_class)->append_header (object, header, value);
 }
 
 static void
@@ -159,10 +168,10 @@ multipart_signed_get_header (GMimeObject *object, const char *header)
 	return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 }
 
-static void
+static gboolean
 multipart_signed_remove_header (GMimeObject *object, const char *header)
 {
-	GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
+	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
 static void
@@ -200,7 +209,7 @@ multipart_signed_write_to_stream (GMimeObject *object, GMimeStream *stream)
  *
  * Creates a new MIME multipart/signed object.
  *
- * Returns an empty MIME multipart/signed object.
+ * Returns: an empty MIME multipart/signed object.
  **/
 GMimeMultipartSigned *
 g_mime_multipart_signed_new (void)
@@ -228,7 +237,7 @@ g_mime_multipart_signed_new (void)
 static void
 sign_prepare (GMimeObject *mime_part)
 {
-	GMimePartEncodingType encoding;
+	GMimeContentEncoding encoding;
 	GMimeObject *subpart;
 	
 	if (GMIME_IS_MULTIPART (mime_part)) {
@@ -249,11 +258,11 @@ sign_prepare (GMimeObject *mime_part)
 		subpart = GMIME_MESSAGE_PART (mime_part)->message->mime_part;
 		sign_prepare (subpart);
 	} else {
-		encoding = g_mime_part_get_encoding (GMIME_PART (mime_part));
+		encoding = g_mime_part_get_content_encoding (GMIME_PART (mime_part));
 		
-		if (encoding != GMIME_PART_ENCODING_BASE64)
-			g_mime_part_set_encoding (GMIME_PART (mime_part),
-						  GMIME_PART_ENCODING_QUOTEDPRINTABLE);
+		if (encoding != GMIME_CONTENT_ENCODING_BASE64)
+			g_mime_part_set_content_encoding (GMIME_PART (mime_part),
+							  GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE);
 	}
 }
 
@@ -272,7 +281,7 @@ sign_prepare (GMimeObject *mime_part)
  * successful, the signed #GMimeObject is set as the signed part of
  * the multipart/signed object @mps.
  *
- * Returns %0 on success or %-1 on fail. If the signing fails, an
+ * Returns: %0 on success or %-1 on fail. If the signing fails, an
  * exception will be set on @err to provide information as to why the
  * failure occured.
  **/
@@ -327,7 +336,7 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
 	sigstream = g_mime_stream_mem_new ();
 	
 	/* sign the content stream */
-	if (g_mime_cipher_sign (ctx, userid, hash, filtered_stream, sigstream, err) == -1) {
+	if (g_mime_cipher_context_sign (ctx, userid, hash, filtered_stream, sigstream, err) == -1) {
 		g_object_unref (filtered_stream);
 		g_object_unref (sigstream);
 		g_object_unref (stream);
@@ -353,7 +362,7 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
 	g_object_unref (wrapper);
 	
 	mps->protocol = g_strdup (ctx->sign_protocol);
-	mps->micalg = g_strdup (g_mime_cipher_hash_name (ctx, hash));
+	mps->micalg = g_strdup (g_mime_cipher_context_hash_name (ctx, hash));
 	
 	/* set the content-type of the signature part */
 	content_type = g_mime_content_type_new_from_string (mps->protocol);
@@ -363,8 +372,8 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
 	 * the CipherContext class - maybe ::sign can take/output a
 	 * GMimePart instead. */
 	if (!g_ascii_strcasecmp (mps->protocol, "application/pkcs7-signature")) {
+		g_mime_part_set_content_encoding (GMIME_PART (signature), GMIME_CONTENT_ENCODING_BASE64);
 		g_mime_part_set_filename (GMIME_PART (signature), "smime.p7m");
-		g_mime_part_set_encoding (GMIME_PART (signature), GMIME_PART_ENCODING_BASE64);
 	}
 	
 	/* save the content and signature parts */
@@ -392,8 +401,8 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
  * Attempts to verify the signed MIME part contained within the
  * multipart/signed object @mps using the @ctx cipher context.
  *
- * Returns a new #GMimeCipherValidity object on success or %NULL on
- * fail. If the signing fails, an exception will be set on @err to
+ * Returns: a new #GMimeSignatureValidity object on success or %NULL
+ * on fail. If the signing fails, an exception will be set on @err to
  * provide information as to why the failure occured.
  **/
 GMimeSignatureValidity *
@@ -414,8 +423,9 @@ g_mime_multipart_signed_verify (GMimeMultipartSigned *mps, GMimeCipherContext *c
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), NULL);
 	g_return_val_if_fail (ctx->sign_protocol != NULL, NULL);
 	
-	if (g_mime_multipart_get_number ((GMimeMultipart *) mps) != 2) {
-		/* FIXME: set an exception */
+	if (g_mime_multipart_get_number ((GMimeMultipart *) mps) < 2) {
+		g_set_error (err, GMIME_ERROR, GMIME_ERROR_PARSE_ERROR, "%s",
+			     "Cannot verify multipart/signed part due to missing subparts.");
 		return NULL;
 	}
 	
@@ -480,8 +490,8 @@ g_mime_multipart_signed_verify (GMimeMultipartSigned *mps, GMimeCipherContext *c
 	g_object_unref (wrapper);
 	
 	/* verify the signature */
-	hash = g_mime_cipher_hash_id (ctx, mps->micalg);
-	valid = g_mime_cipher_verify (ctx, hash, stream, sigstream, err);
+	hash = g_mime_cipher_context_hash_id (ctx, mps->micalg);
+	valid = g_mime_cipher_context_verify (ctx, hash, stream, sigstream, err);
 	
 	d(printf ("attempted to verify:\n----- BEGIN SIGNED PART -----\n%.*s----- END SIGNED PART -----\n",
 		  (int) GMIME_STREAM_MEM (stream)->buffer->len, GMIME_STREAM_MEM (stream)->buffer->data));
