@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -109,9 +109,9 @@ test_sign (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphert
 	GError *err = NULL;
 	Exception *ex;
 	
-	g_mime_cipher_sign (ctx, "no.user@no.domain",
-			    GMIME_CIPHER_HASH_DEFAULT,
-			    cleartext, ciphertext, &err);
+	g_mime_cipher_context_sign (ctx, "no.user@no.domain",
+				    GMIME_CIPHER_HASH_DEFAULT,
+				    cleartext, ciphertext, &err);
 	
 	if (err != NULL) {
 		ex = exception_new ("%s", err->message);
@@ -131,8 +131,8 @@ test_verify (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphe
 	GError *err = NULL;
 	Exception *ex;
 	
-	validity = g_mime_cipher_verify (ctx, GMIME_CIPHER_HASH_DEFAULT,
-					 cleartext, ciphertext, &err);
+	validity = g_mime_cipher_context_verify (ctx, GMIME_CIPHER_HASH_DEFAULT,
+						 cleartext, ciphertext, &err);
 	
 	if (validity == NULL) {
 		ex = exception_new ("%s", err->message);
@@ -158,8 +158,8 @@ test_encrypt (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciph
 	recipients = g_ptr_array_new ();
 	g_ptr_array_add (recipients, "no.user@no.domain");
 	
-	g_mime_cipher_encrypt (ctx, FALSE, "no.user@no.domain", recipients,
-			       cleartext, ciphertext, &err);
+	g_mime_cipher_context_encrypt (ctx, FALSE, "no.user@no.domain", recipients,
+				       cleartext, ciphertext, &err);
 	
 	g_ptr_array_free (recipients, TRUE);
 	
@@ -184,7 +184,7 @@ test_decrypt (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciph
 	
 	stream = g_mime_stream_mem_new ();
 	
-	g_mime_cipher_decrypt (ctx, ciphertext, stream, &err);
+	g_mime_cipher_context_decrypt (ctx, ciphertext, stream, &err);
 	
 	if (err != NULL) {
 		g_object_unref (stream);
@@ -209,8 +209,10 @@ static void
 test_export (GMimeCipherContext *ctx, const char *path)
 {
 	GMimeStream *istream, *ostream;
+	register const char *inptr;
+	const char *inbuf, *outbuf;
+	size_t inlen, outlen;
 	Exception *ex = NULL;
-	GByteArray *buf[2];
 	GError *err = NULL;
 	GPtrArray *keys;
 	int fd;
@@ -229,7 +231,7 @@ test_export (GMimeCipherContext *ctx, const char *path)
 	
 	ostream = g_mime_stream_mem_new ();
 	
-	g_mime_cipher_export_keys (ctx, keys, ostream, &err);
+	g_mime_cipher_context_export_keys (ctx, keys, ostream, &err);
 	g_ptr_array_free (keys, TRUE);
 	if (err != NULL) {
 		ex = exception_new ("%s", err->message);
@@ -239,10 +241,25 @@ test_export (GMimeCipherContext *ctx, const char *path)
 		throw (ex);
 	}
 	
-	buf[0] = GMIME_STREAM_MEM (istream)->buffer;
-	buf[1] = GMIME_STREAM_MEM (ostream)->buffer;
+	inbuf = GMIME_STREAM_MEM (istream)->buffer->data;
+	inlen = GMIME_STREAM_MEM (istream)->buffer->len;
+	if ((inptr = strstr (inbuf, "\n\n"))) {
+		/* skip past the headers which may have different version numbers */
+		inptr += 2;
+		inlen -= (inptr - inbuf);
+		inbuf = inptr;
+	}
 	
-	if (buf[0]->len != buf[1]->len || memcmp (buf[0]->data, buf[1]->data, buf[0]->len) != 0)
+	outbuf = GMIME_STREAM_MEM (ostream)->buffer->data;
+	outlen = GMIME_STREAM_MEM (ostream)->buffer->len;
+	if ((inptr = strstr (outbuf, "\n\n"))) {
+		/* skip past the headers which may have different version numbers */
+		inptr += 2;
+		outlen -= (inptr - outbuf);
+		outbuf = inptr;
+	}
+	
+	if (outlen != inlen || memcmp (outbuf, inbuf, inlen) != 0)
 		ex = exception_new ("exported key does not match original key");
 	
 	g_object_unref (istream);
@@ -264,7 +281,7 @@ import_key (GMimeCipherContext *ctx, const char *path)
 		throw (exception_new ("open() failed: %s", strerror (errno)));
 	
 	stream = g_mime_stream_fs_new (fd);
-	g_mime_cipher_import_keys (ctx, stream, &err);
+	g_mime_cipher_context_import_keys (ctx, stream, &err);
 	g_object_unref (stream);
 	
 	if (err != NULL) {
